@@ -204,8 +204,8 @@ journal_GET <- function(x, args, works, cursor = NULL, cursor_max = NULL,
 
   if (!is.null(cursor) && works) {
     rr <- Requestor$new(path = path, args = args, cursor_max = cursor_max,
-                        should_parse = TRUE, .progress = .progress, ...)
-    rr$GETcursor()
+                        should_parse = TRUE, .progress = .progress)
+    rr$GETcursor(...)
     rr$parse()
   } else {
     cr_GET(endpoint = path, args, todf = FALSE, parse = TRUE, ...)
@@ -222,8 +222,8 @@ journal_GET_ <- function(x, args, works, cursor = NULL, cursor_max = NULL,
 
   if (!is.null(cursor) && works) {
     rr <- Requestor$new(path = path, args = args, cursor_max = cursor_max,
-                        should_parse = parse, .progress = .progress, ...)
-    rr$GETcursor()
+                        should_parse = parse, .progress = .progress)
+    rr$GETcursor(...)
     rr$cursor_out
   } else {
     cr_GET(endpoint = path, args, todf = FALSE, parse = parse, ...)
