@@ -160,8 +160,8 @@ member_GET <- function(x, args, works, cursor = NULL, cursor_max = NULL, .progre
 
   if (!is.null(cursor) && works) {
     rr <- Requestor$new(path = path, args = args, cursor_max = cursor_max,
-                        should_parse = TRUE, .progress = .progress, ...)
-    rr$GETcursor()
+                        should_parse = TRUE, .progress = .progress)
+    rr$GETcursor(...)
     rr$parse()
   } else {
     cr_GET(endpoint = path, args, FALSE, parse = TRUE, ...)
@@ -178,8 +178,8 @@ member_GET_ <- function(x, args, works, cursor = NULL, cursor_max = NULL,
 
   if (!is.null(cursor) && works) {
     rr <- Requestor$new(path = path, args = args, cursor_max = cursor_max,
-                        should_parse = parse, .progress = .progress, ...)
-    rr$GETcursor()
+                        should_parse = parse, .progress = .progress)
+    rr$GETcursor(...)
     rr$cursor_out
   } else {
     cr_GET(path, args, FALSE, parse = parse, ...)
