@@ -54,8 +54,6 @@
 #' cr_types_('monograph', parse = TRUE)
 #' cr_types_("journal-article", works = TRUE, cursor = "*",
 #'    cursor_max = 300, limit = 100)
-#' cr_types_("journal-article", works = TRUE, cursor = "*",
-#'    cursor_max = 300, limit = 100, parse = TRUE)
 #'
 #' # field queries
 #' ## query.container-title
@@ -167,8 +165,8 @@ types_GET <- function(x, args, works, cursor = NULL, cursor_max = NULL,
 
   if (!is.null(cursor) && works) {
     rr <- Requestor$new(path = path, args = args, cursor_max = cursor_max,
-                        should_parse = TRUE, .progress = .progress, ...)
-    rr$GETcursor()
+                        should_parse = TRUE, .progress = .progress)
+    rr$GETcursor(...)
     rr$parse()
   } else {
     cr_GET(path, args, todf = FALSE, ...)
@@ -186,8 +184,8 @@ types_GET_ <- function(x, args, works, cursor = NULL, cursor_max = NULL,
 
   if (!is.null(cursor) && works) {
     rr <- Requestor$new(path = path, args = args, cursor_max = cursor_max,
-                        should_parse = parse, .progress = .progress, ...)
-    rr$GETcursor()
+                        should_parse = parse, .progress = .progress)
+    rr$GETcursor(...)
     rr$cursor_out
   } else {
     cr_GET(path, args, todf = FALSE, parse = parse, ...)
